package org.xbib.content.rdf.io.rdfxml;

import org.xbib.content.rdf.RdfContent;
import org.xbib.content.rdf.RdfContentBuilder;
import org.xbib.content.rdf.RdfContentGenerator;
import org.xbib.content.rdf.RdfContentParser;
import org.xbib.content.rdf.StandardRdfContentType;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

public class RdfXmlContent implements RdfContent<RdfXmlContentParams> {

    private static final RdfXmlContent RDF_XML_CONTENT = new RdfXmlContent();

    private RdfXmlContent() {
    }

    public static RdfXmlContent rdfXmlContent() {
        return RDF_XML_CONTENT;
    }

    public static RdfContentBuilder<RdfXmlContentParams> contentBuilder(RdfXmlContentParams params) throws IOException {
        return new RdfContentBuilder<>(RDF_XML_CONTENT, params);
    }

    public static RdfContentBuilder<RdfXmlContentParams> contentBuilder(RdfXmlContentParams params, OutputStream outputStream)
            throws IOException {
        return new RdfContentBuilder<>(RDF_XML_CONTENT, params, outputStream);
    }

    @Override
    public StandardRdfContentType type() {
        return StandardRdfContentType.RDFXML;
    }

    @Override
    public RdfContentGenerator<RdfXmlContentParams> createGenerator(RdfXmlContentParams params, OutputStream outputStream) throws IOException {
        return new RdfXmlContentGenerator(params, outputStream);
    }

    @Override
    public RdfContentParser<RdfXmlContentParams> createParser(RdfXmlContentParams params, InputStream inputStream) throws IOException {
        return new RdfXmlContentParser<>(params, inputStream);
    }
}
