package org.xbib.content.rdf.test.io.rdfxml;

import static org.xbib.content.rdf.RdfContentFactory.ntripleBuilder;
import static org.xbib.content.rdf.RdfContentFactory.turtleBuilder;

import org.junit.jupiter.api.Test;
import org.xbib.content.rdf.io.ntriple.NTripleContentParams;
import org.xbib.content.rdf.io.rdfxml.RdfXmlContentParser;
import org.xbib.content.rdf.io.turtle.TurtleContentParams;
import org.xbib.content.resource.IRINamespaceContext;
import org.xbib.content.rdf.test.StreamTester;

import java.io.InputStream;

public class GNDRdfXmlReaderTest extends StreamTester {

    @Test
    public void testGNDfromRdfXmltoTurtle() throws Exception {
        String filename = "GND.rdf";
        try (InputStream inputStream = getClass().getResourceAsStream(filename)) {
            IRINamespaceContext namespaceContext = IRINamespaceContext.newInstance(getClass());
            TurtleContentParams params = new TurtleContentParams(namespaceContext, false);
            RdfXmlContentParser<TurtleContentParams> reader = new RdfXmlContentParser<>(params, inputStream);
            StringBuilder sb = new StringBuilder();
            reader.setRdfContentBuilderProvider(() -> turtleBuilder(params));
            reader.setRdfContentBuilderHandler(builder -> sb.append(builder.string()));
            reader.parse();
            assertStream("gnd.ttl", getClass().getResourceAsStream("gnd.ttl"), sb.toString());
        }
    }

    @Test
    public void testAnotherGNDfromRdfXmltoTurtle() throws Exception {
        String filename = "GND.rdf";
        try (InputStream inputStream = getClass().getResourceAsStream(filename)) {
            IRINamespaceContext namespaceContext = IRINamespaceContext.newInstance(getClass());
            TurtleContentParams params = new TurtleContentParams(namespaceContext, false);
            RdfXmlContentParser<TurtleContentParams> reader = new RdfXmlContentParser<>(params, inputStream);
            StringBuilder sb = new StringBuilder();
            reader.setRdfContentBuilderProvider(() -> turtleBuilder(params));
            reader.setRdfContentBuilderHandler(builder -> sb.append(builder.string()));
            reader.parse();
            assertStream("gnd.ttl", getClass().getResourceAsStream("gnd.ttl"), sb.toString());
        }
    }

    @Test
    public void testGNDtoNtriple() throws Exception {
        String filename = "GND.rdf";
        try (InputStream inputStream = getClass().getResourceAsStream(filename)) {
            IRINamespaceContext namespaceContext = IRINamespaceContext.newInstance(getClass());
            NTripleContentParams params = new NTripleContentParams(namespaceContext);
            RdfXmlContentParser<NTripleContentParams> reader = new RdfXmlContentParser<>(params, inputStream);
            StringBuilder sb = new StringBuilder();
            reader.setRdfContentBuilderProvider(() -> ntripleBuilder(params));
            reader.setRdfContentBuilderHandler(builder -> sb.append(builder.string()));
            reader.parse();
            assertStream("GND.nt", getClass().getResourceAsStream("GND.nt"), sb.toString());
        }
    }
}
