package org.xbib.content.xml.test.json;

import org.junit.jupiter.api.Test;
import org.xbib.content.xml.XmlNamespaceContext;
import org.xbib.content.xml.json.JsonXmlReader;
import org.xbib.content.xml.json.JsonXmlStreamer;
import org.xml.sax.InputSource;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.io.StringWriter;
import java.io.Writer;
import java.nio.charset.StandardCharsets;
import javax.xml.namespace.QName;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.sax.SAXSource;
import javax.xml.transform.stream.StreamResult;

public class Json2XmlTest {

    @Test
    public void testJSON() throws Exception {
        String[] jsons = {
                "dc",
                "elasticsearch-hit-example-1",
                "es-test-20130719",
                "glossary",
                "menu"
        };
        for (String s : jsons) {
            testJSONXmlReader(s);
            testJSONStreamer(s);
        }
    }

    private void testJSONXmlReader(String path) throws Exception {
        try (InputStream inputStream = getClass().getResourceAsStream(path + ".json");
             Reader reader = new InputStreamReader(inputStream, StandardCharsets.UTF_8);
             Writer writer = new StringWriter()) {
            JsonXmlReader parser = new JsonXmlReader().root(root()).context(context());
            TransformerFactory tFactory = TransformerFactory.newInstance();
            Transformer transformer = tFactory.newTransformer();
            StreamResult stream = new StreamResult(writer);
            transformer.transform(new SAXSource(parser, new InputSource(reader)), stream);
        }
    }

    private void testJSONStreamer(String path) throws Exception {
        try (InputStream inputStream = getClass().getResourceAsStream(path + ".json");
            Reader reader = new InputStreamReader(inputStream, StandardCharsets.UTF_8);
            Writer writer = new StringWriter()) {
            JsonXmlStreamer jsonXml = new JsonXmlStreamer().root(root()).context(context());
            jsonXml.toXML(reader, writer);
        }
    }

    private QName root() {
        return new QName("http://elasticsearch.org/ns/1.0/", "result", "es");
    }

    private XmlNamespaceContext context() {
        XmlNamespaceContext context = XmlNamespaceContext.newInstance(getClass());
        context.addNamespace("bib", "info:srw/cql-context-set/1/bib-v1/");
        context.addNamespace("xbib", "http://xbib.org/");
        context.addNamespace("abc", "http://localhost/");
        context.addNamespace("lia", "http://xbib.org/namespaces/lia/");
        return context;
    }
}
